﻿using System.Windows;
using System.Windows.Input;
using ThinkGeo.Core;
using ThinkGeo.UI.Wpf;

namespace TrackZoomSample
{
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void CommonCommandBinding_CanExecute(object sender, CanExecuteRoutedEventArgs e)
        {
            e.CanExecute = true;
        }

        private void Pan_OnExecuted(object sender, ExecutedRoutedEventArgs e)
        {
            MapView.ExtentOverlay.TrackZoomInKey = Key.LeftCtrl;
            MapView.ExtentOverlay.TrackZoomInMouseButton = MapMouseButton.Left;
        }

        private void ZoomIn_OnExecuted(object sender, ExecutedRoutedEventArgs e)
        {
            MapView.ExtentOverlay.TrackZoomInKey = Key.None;
            MapView.ExtentOverlay.TrackZoomInMouseButton = MapMouseButton.Left;
        }

        private void ZoomOut_OnExecuted(object sender, ExecutedRoutedEventArgs e)
        {
            _ = MapView.ZoomOutAsync();
        }

        private async void MapView_Loaded(object sender, RoutedEventArgs e)
        {
            MapView.MapUnit = GeographyUnit.DecimalDegree;

            string worldLayerFilePath = @"./../../../../world-administrative-boundaries/world-administrative-boundaries.shp";
            ShapeFileFeatureLayer worldLayer = new ShapeFileFeatureLayer(worldLayerFilePath);
            worldLayer.Projection = new Projection(Projection.ConvertEpsgToProjString(25832));
            AreaStyle areaStyle = new AreaStyle();
            areaStyle.FillBrush = new GeoSolidBrush(GeoColor.FromArgb(255, 233, 232, 214));
            areaStyle.OutlinePen = new GeoPen(GeoColor.FromArgb(255, 118, 138, 69), 1);
            areaStyle.OutlinePen.DashStyle = LineDashStyle.Solid;

            worldLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = areaStyle;
            worldLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            LayerOverlay layerOverlay = new LayerOverlay();
            layerOverlay.Layers.Add(new BackgroundLayer(new GeoSolidBrush(GeoColors.ShallowOcean)));
            layerOverlay.Layers.Add(worldLayer);
            
            MapView.Overlays.Add(layerOverlay);

            MapView.CurrentExtent = new RectangleShape(-136.60, 60.06, -53.81, 11.63);
            await MapView.RefreshAsync();
        }
    }

    public static class MyCommands
    {
        public static RoutedUICommand Pan { get; } = new RoutedUICommand("Pan", "Pan", typeof(MyCommands));
        public static RoutedUICommand ZoomIn { get; } = new RoutedUICommand("ZoomIn", "ZoomIn", typeof(MyCommands));
        public static RoutedUICommand ZoomOut { get; } = new RoutedUICommand("ZoomOut", "ZoomOut", typeof(MyCommands));
    }
}